@@ -2,14 +2,18 @@ import hashlib
 import base64
 import base32hex
 from .make_hashable import represent_and_encode
+from ._get_number_of_cores import get_number_of_jobs
 
 
-def hash_object(obj, n_jobs, base=64):
+def hash_object(obj, n_jobs=None, base=64):
 	"""
 	:type obj: Obj
 	:type base: int
 	:rtype str
 	"""
+	if n_jobs is None:
+		n_jobs = get_number_of_jobs()
+
 	if hasattr(obj, '__hash64__') and base == 64:
 		return obj.__hash64__()
 	elif hasattr(obj, '__hash32__') and base == 32:
