@@ -1,9 +1,10 @@
 import functools
 from disk import Path
 from .Cache import Cache
+from ._get_number_of_cores import get_number_of_jobs
 
 
-def memoize(path, n_jobs, exclude_kwargs=None, s3=None, id=0, echo=1, *kwargs):
+def memoize(path, n_jobs=None, exclude_kwargs=None, s3=None, id=0, echo=1, *kwargs):
 	"""
 	makes a decorator for memoizing a function
 	:type path: amazonian.S3.S3Path or Path or str
@@ -11,9 +12,12 @@ def memoize(path, n_jobs, exclude_kwargs=None, s3=None, id=0, echo=1, *kwargs):
 	:type id: int
 	:type exclude_kwargs: list or tuple
 	:type s3: amazonian.S3.S3
-	:type _spark: pyspark.sql.session.SparkSession
+	:type spark: pyspark.sql.session.SparkSession
 	:rtype: callable
 	"""
+	if n_jobs is None:
+		n_jobs = get_number_of_jobs()
+
 	if 'spark' in kwargs:
 		spark = kwargs['spark']
 	elif 'spark' in locals() or 'spark' in globals():
